@@ -47,7 +47,7 @@ def _run(local, remote):
 
 
 def start(localFunction, remoteFunction):
-    start_server = _websockets.serve(_run(localFunction, remoteFunction), '0.0.0.0', 8881)
+    start_server = _websockets.serve(_run(localFunction, remoteFunction), '0.0.0.0', 8881,  max_size=1048576000)
     print("Python microservice started on 8881")
     _asyncio.get_event_loop().run_until_complete(start_server)
     _asyncio.get_event_loop().run_forever()
